@@ -1,10 +1,14 @@
 #' Extract tagged variables of a linelist object
 #'
-#' This function is used to create a `data.frame` of tagged variables from a
-#' `linelist` object, and runs [dplyr::select] on the output. It is equivalent
-#' to running successively [tags_df()] and [dplyr::select()] on a
-#' `linelist` object. Note that the output no longer is a `linelist` object, but
-#' a regular `data.frame` (or `tibble`).
+#' @keywords deprecated
+#' @description
+#' `r lifecycle::badge("deprecated")`
+
+#' This function was  equivalent to running successively [tags_df()] and
+#' [dplyr::select()] on a `linelist` object.
+#' To encourage users to understand what is going on and in order to follow the
+#' software engineering good practice of providing just one way to do a given
+#' task, this function is now deprecated.
 #'
 #' @param x a `linelist` object
 #'
@@ -20,7 +24,7 @@
 #' @seealso
 #' * [tags()] for existing tags in a `linelist`
 #' * [tags_df()] to get a `data.frame` of all tags
-#' 
+#'
 #' @examples
 #' if (require(outbreaks)) {
 #'
@@ -29,20 +33,39 @@
 #'
 #'   ## create linelist
 #'   x <- make_linelist(measles_hagelloch_1861,
-#'                      id = "case_ID",
-#'                      date_onset = "date_of_prodrome",
-#'                      age = "age",
-#'                      gender = "gender")
+#'     id = "case_ID",
+#'     date_onset = "date_of_prodrome",
+#'     age = "age",
+#'     gender = "gender"
+#'   )
 #'   head(x)
-#' 
+#'
 #'   ## check tagged variables
 #'   tags(x)
-#' 
-#'   ## extract tagged variables
+#'
+#'   # DEPRECATED!
 #'   select_tags(x, "gender", "age")
+#'
+#'   # Instead, use:
+#'   library(dplyr)
+#'   x %>%
+#'     tags_df() %>%
+#'     select(gender, age)
 #' }
-
+#'
 select_tags <- function(x, ...) {
+
+  lifecycle::deprecate_warn(
+    "1.0.0",
+    "select_tags()",
+    details =
+      paste(
+        "This function is deprecated:",
+        "use the two step `tags_df()` and `dplyr::select()` process instead"
+      )
+  )
+
   df <- tags_df(x)
   dplyr::select(df, ...)
+
 }
