@@ -1,8 +1,6 @@
 if (require(testthat)) {
-  library(linelist)
+  library(linelist)  # nolint
   test_check("linelist")
 } else {
   warning("'linelist' requires 'testthat' for tests")
 }
-
-
